translate.convert.csv2po.csv2po

Package translate :: Package convert :: Module csv2po :: Class csv2po |
[hide private]
[frames] | no frames]

# Class csv2po

source code

a class that takes translations from a .csv file and puts them in a .po file

Instance Methods | [hide private]
__init__(self, templatepo=None, charset=None, duplicatestyle="keep") construct the converter... | source code
makeindex(self) makes indexes required for searching... | source code
convertunit(self, csvunit) converts csv unit to po unit | source code
handlecsvunit(self, csvunit) handles reintegrating a csv unit into the .po file | source code
convertstore(self, thecsvfile) converts a csvfile to a pofile, and returns it. | source code

Method Details | [hide private]

### convertstore(self, thecsvfile) | source code
converts a csvfile to a pofile, and returns it. uses templatepo if given at construction